package com.abcsz.litigationcase.service.impl;

import com.abcsz.litigationcase.dao.entity.LawFirmEntity;
import com.abcsz.litigationcase.dao.entity.UserEntity;
import com.abcsz.litigationcase.dao.mapper.LawFirmMapper;
import com.abcsz.litigationcase.domain.ro.LawFirmQueryRo;
import com.abcsz.litigationcase.domain.ro.LawFirmRo;
import com.abcsz.litigationcase.domain.vo.LawFirmQueryVo;
import com.abcsz.litigationcase.domain.vo.PublicVo;
import com.abcsz.litigationcase.service.LawFirmService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 律师事务所信息 服务实现类
 * </p>
 *
 * @author shengqianlei
 * @since 2022-04-21
 */
@Slf4j
@Service
public class LawFirmServiceIml extends ServiceImpl<LawFirmMapper, LawFirmEntity> implements LawFirmService {

    @Autowired
    private LawFirmMapper lawFirmMapper;


    @Override
    public LawFirmQueryVo lawFirmQuery(LawFirmQueryRo ro) {
        log.info("查询用户信息...");
        LawFirmQueryVo lawFirmQueryVo = new LawFirmQueryVo();
        List<LawFirmEntity> lawFirmEntities = null;
        try {
            if (ro.getLawFirmCode() == null) {
                QueryWrapper<LawFirmEntity> queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("del_flag", 0);
                lawFirmEntities = lawFirmMapper.selectList(queryWrapper);
            }
            if(ro.getLawFirmCode()!=null){
                QueryWrapper<LawFirmEntity> queryWrapper1 = new QueryWrapper<>();
                queryWrapper1.eq("law_firm_code",ro.getLawFirmCode());
                queryWrapper1.eq("del_flag", 0);
                lawFirmEntities = lawFirmMapper.selectList(queryWrapper1);
            }

            if (lawFirmEntities == null) {
                lawFirmQueryVo.setRetCode("S001");
                lawFirmQueryVo.setRetMsg("查询异常，请重新操作");
                log.info(lawFirmQueryVo.getRetCode() + "****" + lawFirmQueryVo.getRetMsg());
                return lawFirmQueryVo;
            }
            if (lawFirmEntities.size() == 0) {
                lawFirmQueryVo.setRetCode("0000");
                lawFirmQueryVo.setRetMsg("查询成功，无相关信息");
                log.info(lawFirmQueryVo.getRetCode() + "****" + lawFirmQueryVo.getRetMsg());
                return lawFirmQueryVo;
            }
        } catch (Exception e) {
            log.error(e.getMessage() + "****" + e.getStackTrace());
            lawFirmQueryVo.setRetCode("X001");
            lawFirmQueryVo.setRetMsg("系统异常");
            log.error(lawFirmQueryVo.getRetCode() + "****" + lawFirmQueryVo.getRetMsg());
            return lawFirmQueryVo;
        }
        lawFirmQueryVo.setRetCode("0000");
        lawFirmQueryVo.setRetMsg("查询成功");
        lawFirmQueryVo.setData(lawFirmEntities);
        log.info(lawFirmQueryVo.getRetCode() + "****" + lawFirmQueryVo.getRetMsg());
        return lawFirmQueryVo;
    }

    @Override
    public PublicVo lawFirmInsert(LawFirmRo ro) {
        log.info("新增机构信息...");
        PublicVo publicVo = new PublicVo();

        try {
            /* 查询该事务所是否已经存在 */
            QueryWrapper<LawFirmEntity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("law_firm_code", ro.getLawFirmCode());
            queryWrapper.eq("del_flag", 0);
            LawFirmEntity lawFirmEntity = lawFirmMapper.selectOne(queryWrapper);
            if (lawFirmEntity != null) {
                publicVo.setRetCode("Y001");
                publicVo.setRetMsg("该机构信息已存在，请勿重复新增");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

            LawFirmEntity lawFirmEntity1 = new LawFirmEntity();
            lawFirmEntity1.setLawFirmName(ro.getLawFirmName());
            lawFirmEntity1.setLawFirmCode(ro.getLawFirmCode());
            lawFirmEntity1.setLawFirmAddr(ro.getLawFirmAddr());
            lawFirmEntity1.setLawFirmTel(ro.getLawFirmTel());
            lawFirmEntity1.setLawFirmTime(ro.getLawFirmTime());
            lawFirmEntity1.setLawFirmDescripe(ro.getLawFirmDescripe());
            lawFirmEntity1.setLegalPerson(ro.getLegalPerson());
            lawFirmEntity1.setPicture(ro.getPicture());
            lawFirmEntity1.setRegion(ro.getRegion());
            lawFirmEntity1.setCreateTime(new Date());
            lawFirmEntity1.setUpdateTime(new Date());
            lawFirmEntity1.setTxtHold1(ro.getTxtHold1());
            lawFirmEntity1.setTxtHold2(ro.getTxtHold2());
            lawFirmEntity1.setDelFlag(ro.getDelFlag());
            int count1 = lawFirmMapper.insert(lawFirmEntity1);
            if (count1 != 1) {
                publicVo.setRetCode("S001");
                publicVo.setRetMsg("新增机构信息失败，请重新操作");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

        } catch (Exception e) {
            log.error(e.getMessage() + "****" + e.getStackTrace());
            publicVo.setRetCode("X001");
            publicVo.setRetMsg("系统异常");
            log.error(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
            return publicVo;
        }
        publicVo.setRetCode("0000");
        publicVo.setRetMsg("交易成功");
        log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
        return publicVo;
    }

    @Override
    public PublicVo lawFirmModify(LawFirmRo ro) {
        log.info("修改机构信息(包括删除)...");
        PublicVo publicVo = new PublicVo();

        try {
            /* 查询该事务所是否存在 */
            QueryWrapper<LawFirmEntity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("law_firm_code", ro.getLawFirmCode());
            queryWrapper.eq("del_flag", 0);
            LawFirmEntity lawFirmEntity = lawFirmMapper.selectOne(queryWrapper);
            if (lawFirmEntity == null) {
                publicVo.setRetCode("Y001");
                publicVo.setRetMsg("该机构不存在，请先新增");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

            LawFirmEntity lawFirmEntity1 = new LawFirmEntity();
            lawFirmEntity1.setLawFirmName(ro.getLawFirmName());
            lawFirmEntity1.setLawFirmCode(ro.getLawFirmCode());
            lawFirmEntity1.setLawFirmAddr(ro.getLawFirmAddr());
            lawFirmEntity1.setLawFirmTel(ro.getLawFirmTel());
            lawFirmEntity1.setLawFirmTime(ro.getLawFirmTime());
            lawFirmEntity1.setLawFirmDescripe(ro.getLawFirmDescripe());
            lawFirmEntity1.setLegalPerson(ro.getLegalPerson());
            lawFirmEntity1.setPicture(ro.getPicture());
            lawFirmEntity1.setRegion(ro.getRegion());
            lawFirmEntity1.setUpdateTime(new Date());
            lawFirmEntity1.setTxtHold1(ro.getTxtHold1());
            lawFirmEntity1.setTxtHold2(ro.getTxtHold2());
            lawFirmEntity1.setDelFlag(ro.getDelFlag());
            QueryWrapper<LawFirmEntity> queryWrapper1 = new QueryWrapper<>();
            queryWrapper1.eq("law_firm_code", ro.getLawFirmCode());
            queryWrapper1.eq("del_flag", 0);
            int count1 = lawFirmMapper.update(lawFirmEntity1, queryWrapper1);
            if (count1 != 1) {
                publicVo.setRetCode("S001");
                publicVo.setRetMsg("修改机构信息失败，请重新操作");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

        } catch (Exception e) {
            log.error(e.getMessage() + "****" + e.getStackTrace());
            publicVo.setRetCode("X001");
            publicVo.setRetMsg("系统异常");
            log.error(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
            return publicVo;
        }

        publicVo.setRetCode("0000");
        publicVo.setRetMsg("交易成功");
        log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
        return publicVo;
    }

}
