package com.abcsz.litigationcase.service.impl;

import com.abcsz.litigationcase.dao.entity.UserEntity;
import com.abcsz.litigationcase.dao.mapper.UserMapper;
import com.abcsz.litigationcase.domain.ro.UserQueryRo;
import com.abcsz.litigationcase.domain.ro.UserRo;
import com.abcsz.litigationcase.domain.vo.PublicVo;
import com.abcsz.litigationcase.domain.vo.UseQueryVo;
import com.abcsz.litigationcase.service.UserService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 用户的模块权限表 服务实现类
 * </p>
 *
 * @author shengqianlei
 * @since 2022-04-21
 */
@Slf4j
@Service
public class UserServiceIml extends ServiceImpl<UserMapper, UserEntity> implements UserService {

    @Autowired
    private UserMapper userMapper;


    @Override
    public UseQueryVo userQuery(UserQueryRo ro) {
        log.info("查询用户信息...");
        UseQueryVo useQueryVo = new UseQueryVo();
        List<UserEntity> userEntities = null;
        try {
            if (ro.getBankId() != null && ro.getLawFirmId() != null) {
                useQueryVo.setRetCode("Y001");
                useQueryVo.setRetMsg("银行信息和事务所信息不可同时输入");
                log.info(useQueryVo.getRetCode() + "****" + useQueryVo.getRetMsg());
                return useQueryVo;
            }

            /* 无输入 */
            if (ro.getUserIdentity() == null && ro.getBankId() == null && ro.getLawFirmId() == null) {
                log.info("查询所有的用户信息...");
                QueryWrapper<UserEntity> queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("del_flag", 0);
                userEntities = userMapper.selectList(queryWrapper);
            }
            /* 输入身份证信息*/
            if (ro.getUserIdentity() != null) {
                QueryWrapper<UserEntity> queryWrapper1 = new QueryWrapper<>();
                queryWrapper1.eq("user_identity", ro.getUserIdentity());
                queryWrapper1.eq("del_flag", 0);
                userEntities = userMapper.selectList(queryWrapper1);
            }
            /* 只输入银行信息 */
            if (ro.getBankId() != null && ro.getUserIdentity() == null && ro.getLawFirmId() == null) {
                QueryWrapper<UserEntity> queryWrapper2 = new QueryWrapper<>();
                queryWrapper2.eq("bank_id", ro.getBankId());
                queryWrapper2.eq("del_flag", 0);
                userEntities = userMapper.selectList(queryWrapper2);
            }
            /* 只输入律师事务所信息 */
            if (ro.getLawFirmId() != null && ro.getUserIdentity() == null && ro.getBankId() == null) {
                QueryWrapper<UserEntity> queryWrapper2 = new QueryWrapper<>();
                queryWrapper2.eq("law_firm_id", ro.getLawFirmId());
                queryWrapper2.eq("del_flag", 0);
                userEntities = userMapper.selectList(queryWrapper2);
            }

            if (userEntities == null) {
                useQueryVo.setRetCode("S001");
                useQueryVo.setRetMsg("查询异常，请重新操作");
                log.info(useQueryVo.getRetCode() + "****" + useQueryVo.getRetMsg());
                return useQueryVo;
            }
            if (userEntities.size() == 0) {
                useQueryVo.setRetCode("0000");
                useQueryVo.setRetMsg("查询成功，无相关信息");
                log.info(useQueryVo.getRetCode() + "****" + useQueryVo.getRetMsg());
                return useQueryVo;
            }
        } catch (Exception e) {
            log.error(e.getMessage() + "****" + e.getStackTrace());
            useQueryVo.setRetCode("X001");
            useQueryVo.setRetMsg("系统异常");
            log.error(useQueryVo.getRetCode() + "****" + useQueryVo.getRetMsg());
            return useQueryVo;
        }
        useQueryVo.setRetCode("0000");
        useQueryVo.setRetMsg("查询成功");
        useQueryVo.setData(userEntities);
        log.info(useQueryVo.getRetCode() + "****" + useQueryVo.getRetMsg());
        return useQueryVo;
    }

    @Override
    public PublicVo userInsert(UserRo ro) {
        log.info("新增用户信息....");
        PublicVo publicVo = new PublicVo();

        try {
            /* 查询该用户是否已经存在 */
            QueryWrapper<UserEntity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("user_identity", ro.getUserIdentity());
            queryWrapper.eq("del_flag", 0);
            UserEntity userEntity = userMapper.selectOne(queryWrapper);
            if (userEntity != null) {
                publicVo.setRetCode("Y001");
                publicVo.setRetMsg("该用户已存在，请勿重复操作");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

            if (ro.getIsAbc() == 0 && ro.getBankId() == null) {
                publicVo.setRetCode("Y002");
                publicVo.setRetMsg("行内人员请输入所属银行信息");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

            if (ro.getIsAbc() == 1 && ro.getLawFirmId() == null) {
                publicVo.setRetCode("Y003");
                publicVo.setRetMsg("行外人员请输入所属事务所信息");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }
            UserEntity userEntity1 = new UserEntity();
            userEntity1.setUserAccount(ro.getUserAccount());
            userEntity1.setUserPassword(ro.getUserPassword());
            userEntity1.setUserName(ro.getUserName());
            userEntity1.setUserIdentity(ro.getUserIdentity());
            userEntity1.setUserTel(ro.getUserTel());
            userEntity1.setUserEmail(ro.getUserEmail());
            userEntity1.setIsAbc(ro.getIsAbc());
            userEntity1.setLawFirmId(ro.getLawFirmId());
            userEntity1.setModuleConfigure(ro.getModuleConfigure());
            userEntity1.setPermitConfigure(ro.getPermitConfigure());
            userEntity1.setUserDescripe(ro.getUserDescripe());
            userEntity1.setCreateTime(new Date());
            userEntity1.setUpdateTime(new Date());
            userEntity1.setTxtHold1(ro.getTxtHold1());
            userEntity1.setTxtHold2(ro.getTxtHold2());
            userEntity1.setDelFlag(ro.getDelFlag());
            int count1 = userMapper.insert(userEntity1);
            if (count1 != 1) {
                publicVo.setRetCode("S001");
                publicVo.setRetMsg("新增用户信息失败，请重新操作");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

        } catch (Exception e) {
            log.error(e.getMessage() + "****" + e.getStackTrace());
            publicVo.setRetCode("X001");
            publicVo.setRetMsg("系统异常");
            log.error(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
            return publicVo;
        }
        publicVo.setRetCode("0000");
        publicVo.setRetMsg("操作成功");
        log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
        return publicVo;
    }

    @Override
    public PublicVo userModify(UserRo ro) {
        log.info("修改用户信息(包括删除)...");
        PublicVo publicVo = new PublicVo();

        try {
            /* 查询该用户是否存在 */
            QueryWrapper<UserEntity> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("user_identity", ro.getUserIdentity());
            queryWrapper.eq("del_flag", 0);
            UserEntity userEntity = userMapper.selectOne(queryWrapper);
            if (userEntity == null) {
                publicVo.setRetCode("Y001");
                publicVo.setRetMsg("该用户不存在，请先新增");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

            if (ro.getIsAbc() == 0 && ro.getBankId() == null) {
                publicVo.setRetCode("Y002");
                publicVo.setRetMsg("行内人员请输入所属银行信息");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

            if (ro.getIsAbc() == 1 && ro.getLawFirmId() == null) {
                publicVo.setRetCode("Y003");
                publicVo.setRetMsg("行外人员请输入所属事务所信息");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

            UserEntity userEntity1 = new UserEntity();
            userEntity1.setUserAccount(ro.getUserAccount());
            userEntity1.setUserPassword(ro.getUserPassword());
            userEntity1.setUserName(ro.getUserName());
            userEntity1.setUserIdentity(ro.getUserIdentity());
            userEntity1.setUserTel(ro.getUserTel());
            userEntity1.setUserEmail(ro.getUserEmail());
            userEntity1.setIsAbc(ro.getIsAbc());
            userEntity1.setLawFirmId(ro.getLawFirmId());
            userEntity1.setModuleConfigure(ro.getModuleConfigure());
            userEntity1.setPermitConfigure(ro.getPermitConfigure());
            userEntity1.setUserDescripe(ro.getUserDescripe());
            userEntity1.setUpdateTime(new Date());
            userEntity1.setTxtHold1(ro.getTxtHold1());
            userEntity1.setTxtHold2(ro.getTxtHold2());
            userEntity1.setDelFlag(ro.getDelFlag());
            QueryWrapper<UserEntity> queryWrapper1 = new QueryWrapper<>();
            queryWrapper1.eq("user_identity", ro.getUserIdentity());
            queryWrapper1.eq("del_flag", 0);
            int count1 = userMapper.update(userEntity1, queryWrapper1);
            if (count1 != 1) {
                publicVo.setRetCode("S001");
                publicVo.setRetMsg("修改用户信息失败，请重新操作");
                log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
                return publicVo;
            }

        } catch (Exception e) {
            log.error(e.getMessage() + "****" + e.getStackTrace());
            publicVo.setRetCode("X001");
            publicVo.setRetMsg("系统异常");
            log.error(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
            return publicVo;
        }

        publicVo.setRetCode("0000");
        publicVo.setRetMsg("操作成功");
        log.info(publicVo.getRetCode() + "****" + publicVo.getRetMsg());
        return publicVo;
    }
}
